HostMapping

Struct HostMapping 

pub struct HostMapping { /* private fields */ }
A representation of a host mapping of a shared memory region, which will be released when this structure is Drop’d. This is not individually Clone (since it holds ownership of the mapping), or Send or Sync, since it doesn’t ensure any particular synchronization.