pub struct HostGuestMemoryRegion {}Expand description
Type for memory regions that track both host and guest addresses.
When one of these is created, it always ends up in a sandbox quickly. It’s an invariant of this type that as long as one of these is associated with a sandbox, it’s always acceptable to read from it, since a lot of the debug/crashdump/snapshot code does. (Note: this means that writable HostGuestMemoryRegions are not possible to support at the moment).